@@ -6,7 +6,6 @@ use 5.010;
 use utf8;
 
 use Moose;
-no if $] >= 5.018000, warnings => qw(experimental::smartmatch);
 
 has 'key' => (
     is              => 'ro',
@@ -58,14 +57,15 @@ sub add_value {
         (defined $position ? (position => $position):()),
         (defined $raw ? (raw => $raw):()),
     ));
+    return $value;
 }
 
-sub all_scalar_values {
+sub all_scalar_values { ## no perlcritic(RequireArgUnpacking)
     return map { $_->value }
         $_[0]->all_values;
 }
 
-sub all_values {
+sub all_values { ## no perlcritic(RequireArgUnpacking)
     return sort { $a->position <=> $b->position }
         $_[0]->list_values;
 }
@@ -87,18 +87,16 @@ sub consume {
 
 sub serialize {
     my ($self) = @_;
-    given ($self->type) {
-        when ('extra') {
-            return $self->key;
-        }
-        when ('parameter') {
-            return $self->key;
-        }
-        when ('option') {
-            my $key = (length $self->key == 1 ? '-':'--').$self->key;
-            return join(' ',map { $key.' '.$_->value } $self->all_values);
-        }
+    my $type = $self->type;
+    if ($type eq 'extra') {
+        return $self->key;
+    } elsif ($type eq 'parameter') {
+        return $self->key;
+    } elsif ($type eq 'option') {
+        my $key = (length $self->key == 1 ? '-':'--').$self->key;
+        return join(' ',map { $key.' '.$_->value } $self->all_values);
     }
+
     return;
 }
 
@@ -126,6 +124,22 @@ Parameter value or option key
 Arrayref of values. A value is represented by a L<MooseX::App::ParsedArgv::Value>
 object.
 
+=head2 add_value
+
+Append a value
+
+=head2 all_scalar_values
+
+All values as scalars (in supplied order)
+
+=head2 all_values
+
+All values as L<MooseX::App::ParsedArgv::Value> objects (in supplied order)
+
+=head2 last_value
+
+Last value as L<MooseX::App::ParsedArgv::Value> object (as given by supplied order)
+
 =head2 type
 
 Type of element. Can be 'option', 'parameter' or 'extra'
@@ -142,4 +156,8 @@ Consumes element. Dies if element is already consumed
 
 Serializes element (Does not procuce output that is identical with original @ARGV)
 
+=head2 original
+
+Tries to re-create the original input
+
 =cut
\ No newline at end of file
